pub struct ServiceConfig {Show 18 fields
pub addr: SocketAddr,
pub number_of_threads: usize,
pub database_batch_size: usize,
pub block_subscriptions_queue: usize,
pub max_queries_depth: usize,
pub max_queries_complexity: usize,
pub max_queries_recursive_depth: usize,
pub max_queries_resolver_recursive_depth: usize,
pub max_queries_directives: usize,
pub max_concurrent_queries: usize,
pub request_body_bytes_limit: usize,
pub required_fuel_block_height_tolerance: u32,
pub required_fuel_block_height_timeout: Duration,
pub query_log_threshold_time: Duration,
pub api_request_timeout: Duration,
pub assemble_tx_dry_run_limit: usize,
pub assemble_tx_estimate_predicates_limit: usize,
pub costs: Costs,
}Fields
addr: SocketAddrnumber_of_threads: usizedatabase_batch_size: usizeblock_subscriptions_queue: usizemax_queries_depth: usizemax_queries_complexity: usizemax_queries_recursive_depth: usizemax_queries_resolver_recursive_depth: usizemax_queries_directives: usizemax_concurrent_queries: usizerequest_body_bytes_limit: usizerequired_fuel_block_height_tolerance: u32Number of blocks that the node can be lagging behind the required fuel block height before it will be considered out of sync.
required_fuel_block_height_timeout: DurationThe time to wait before dropping the request if the node is lagging behind the required fuel block height.
query_log_threshold_time: DurationTime to wait after submitting a query before debug info will be logged about query.
api_request_timeout: Durationassemble_tx_dry_run_limit: usizeassemble_tx_estimate_predicates_limit: usizecosts: CostsConfigurable cost parameters to limit graphql queries complexity