pub enum ChangePolicy {
Change(Address),
Destroy,
}Variants
Change(Address)
Adds Output::Change to the transaction if it is not already present.
Sending remaining assets to the provided address.
Destroy
Destroys the remaining assets by the transaction for provided address.