GenericDatabase

Struct GenericDatabase 

pub struct GenericDatabase<Storage, Metadata> { /* private fields */ }

Implementations

Source

impl GenericDatabase<IterableKeyValueViewWrapper<<OffChain as DatabaseDescription>::Column>, <OffChain as DatabaseDescription>::Height>

Source

impl GenericDatabase<IterableKeyValueViewWrapper<<OnChain as DatabaseDescription>::Column>, <OnChain as DatabaseDescription>::Height>

pub fn latest_compressed_block(&self) -> StorageResult<Option<CompressedBlock>>

pub fn get_current_block(&self) -> StorageResult<Option<CompressedBlock>>

Get the current block at the head of the chain.

pub fn get_full_block( &self, height: &BlockHeight, ) -> StorageResult<Option<Block>>

Retrieve the full block and all associated transactions

Source

impl GenericDatabase<IterableKeyValueViewWrapper<<OnChain as DatabaseDescription>::Column>, <OnChain as DatabaseDescription>::Height>

pub fn block_history_proof( &self, message_block_height: &BlockHeight, commit_block_height: &BlockHeight, ) -> StorageResult<MerkleProof>

Source

impl GenericDatabase<IterableKeyValueViewWrapper<<OffChain as DatabaseDescription>::Column>, <OffChain as DatabaseDescription>::Height>

pub fn owned_coins_ids( &self, owner: &Address, start_coin: Option<UtxoId>, direction: Option<IterDirection>, ) -> impl Iterator<Item = StorageResult<UtxoId>> + '_ + use<'_>

Source

impl GenericDatabase<IterableKeyValueViewWrapper<<OnChain as DatabaseDescription>::Column>, <OnChain as DatabaseDescription>::Height>

pub fn coin(&self, utxo_id: &UtxoId) -> StorageResult<CompressedCoin>

Source

impl GenericDatabase<IterableKeyValueViewWrapper<<OnChain as DatabaseDescription>::Column>, <OnChain as DatabaseDescription>::Height>

Source

impl GenericDatabase<DataSource<OnChain, GenesisStage>, Empty>

Source

impl GenericDatabase<IterableKeyValueViewWrapper<<OffChain as DatabaseDescription>::Column>, <OffChain as DatabaseDescription>::Height>

pub fn owned_message_ids( &self, owner: &Address, start_message_id: Option<Nonce>, direction: Option<IterDirection>, ) -> impl Iterator<Item = StorageResult<Nonce>> + '_ + use<'_>

pub fn message_is_spent(&self, id: &Nonce) -> StorageResult<bool>

Source

impl GenericDatabase<IterableKeyValueViewWrapper<<OnChain as DatabaseDescription>::Column>, <OnChain as DatabaseDescription>::Height>

pub fn all_messages( &self, start: Option<Nonce>, direction: Option<IterDirection>, ) -> impl Iterator<Item = StorageResult<Message>> + '_

pub fn iter_messages( &self, ) -> impl Iterator<Item = StorageResult<TableEntry<Messages>>> + '_

pub fn message_exists(&self, id: &Nonce) -> StorageResult<bool>

Source

impl<Description, Stage> GenericDatabase<DataSource<Description, Stage>, Empty>
where Description: DatabaseDescription, Self: StorageInspect<MetadataTable<Description>, Error = Error>,

pub fn check_version(&self) -> StorageResult<()>

Ensures the version is correct.

pub fn latest_height_from_metadata( &self, ) -> StorageResult<Option<Description::Height>>

pub fn indexation_available(&self, kind: IndexationKind) -> StorageResult<bool>

Source

impl GenericDatabase<IterableKeyValueViewWrapper<<OnChain as DatabaseDescription>::Column>, <OnChain as DatabaseDescription>::Height>

pub fn get_sealed_block_by_height( &self, height: &BlockHeight, ) -> StorageResult<Option<SealedBlock>>

Returns SealedBlock by height. Reusable across different trait implementations

pub fn genesis_height(&self) -> StorageResult<Option<BlockHeight>>

pub fn genesis_block(&self) -> StorageResult<Option<CompressedBlock>>

pub fn get_genesis(&self) -> StorageResult<Genesis>

pub fn get_sealed_block_headers( &self, block_height_range: Range<u32>, ) -> StorageResult<Option<Vec<SealedBlockHeader>>>

pub fn get_sealed_block_header( &self, height: &BlockHeight, ) -> StorageResult<Option<SealedBlockHeader>>

pub fn get_transactions_on_blocks( &self, block_height_range: Range<u32>, ) -> StorageResult<Option<Vec<Transactions>>>

Source

impl GenericDatabase<IterableKeyValueViewWrapper<<OffChain as DatabaseDescription>::Column>, <OffChain as DatabaseDescription>::Height>

pub fn owned_transactions( &self, owner: Address, start: Option<OwnedTransactionIndexCursor>, direction: Option<IterDirection>, ) -> impl Iterator<Item = StorageResult<(TxPointer, Bytes32)>> + '_

Iterates over a KV mapping of [address + block height + tx idx] => transaction id. This allows for efficient lookup of transaction ids associated with an address, sorted by block age and ordering within a block. The cursor tracks the [block height + tx idx] for pagination purposes.

pub fn get_tx_status( &self, id: &Bytes32, ) -> StorageResult<Option<TransactionExecutionStatus>>

Source

impl GenericDatabase<IterableKeyValueViewWrapper<<OnChain as DatabaseDescription>::Column>, <OnChain as DatabaseDescription>::Height>

Source

impl<DbDesc> GenericDatabase<DataSource<DbDesc, RegularStage<DbDesc>>, Empty>
where DbDesc: DatabaseDescription,

pub fn entries<'a, T>( &'a self, prefix: Option<Vec<u8>>, direction: IterDirection, ) -> impl Iterator<Item = StorageResult<TableEntry<T>>> + 'a
where T: Mappable + 'a, Self: IterableTable<T>,

pub fn shutdown(self)

Source

impl<Description> GenericDatabase<DataSource<Description, GenesisStage>, Empty>
where Description: DatabaseDescription,

pub fn new(data_source: DataSourceType<Description>) -> Self

Source

impl<Description> GenericDatabase<DataSource<Description, RegularStage<Description>>, Empty>
where Description: DatabaseDescription, Database<Description>: StorageInspect<MetadataTable<Description>, Error = Error>,

pub fn new(data_source: DataSourceType<Description>) -> Self

pub fn open_rocksdb( path: &Path, state_rewind_policy: StateRewindPolicy, database_config: DatabaseConfig, ) -> Result<Self>

pub fn into_genesis( self, ) -> Result<GenesisDatabase<Description>, GenesisDatabase<Description>>

Converts the regular database to an unchecked database.

Returns an error in the case regular database is initialized with the GenesisDatabase, to highlight that it is a bad idea and it is unsafe.

Source

impl<Description, Stage> GenericDatabase<DataSource<Description, Stage>, Empty>
where Description: DatabaseDescription, Stage: Default,

pub fn in_memory() -> Self

pub fn rocksdb_temp( state_rewind_policy: StateRewindPolicy, database_config: DatabaseConfig, ) -> Result<Self>

Source

impl<Description> GenericDatabase<DataSource<Description, RegularStage<Description>>, Empty>
where Description: DatabaseDescription,

Source

impl<Storage, Metadata> GenericDatabase<Storage, Metadata>

pub fn inner_storage(&self) -> &Storage

pub fn metadata(&self) -> Option<&Metadata>

pub fn from_storage_and_metadata( storage: Storage, metadata: Option<Metadata>, ) -> Self

pub fn into_inner(self) -> (Storage, Option<Metadata>)

Source

impl<Column, Height> GenericDatabase<IterableKeyValueViewWrapper<Column>, Height>
where Column: StorageColumn + 'static,

pub fn into_key_value_view(self) -> KeyValueView<Column, Height>

Downgrades the IterableKeyValueView into the KeyValueView.